@@ -1,4 +1,4 @@
-# Use %matplotlib notebook instead of %matplotlib inline to get embedded interactive figures in the IPython notebook.  
+﻿# Use %matplotlib notebook instead of %matplotlib inline to get embedded interactive figures in the IPython notebook.  
 # This requires recent versions of matplotlib (1.4+) and IPython (3.0+)
 # Need to restart notebook or kernel and call %matplotlib notebook twice
 
